# twist-op

An order parameter for water with an interesting twist.



## What is twist?

Twist captures the torsion of the dihedral angles of the tetrahedral network-forming materials. Here is a [Newman projection](https://en.wikipedia.org/wiki/Newman_projection) of a bond in the network.

<img src="https://raw.githubusercontent.com/vitroid/twist-op/master/NodeBox1/twist1.gif" />

Two conformations, staggered and eclipsed, are thought to be special for alkanes. They are also special for water because water ice only has these two conformations in its crystal structure.


